@@ -94,8 +94,7 @@ class ActionRemoveDoc(SimpleAction):
             return
         model.remove(selection_iter)
         for (line_idx, line) in enumerate(
-                    self.__dialog.lists['docs']['model']
-                ):
+                self.__dialog.lists['docs']['model']):
             if not self.__dialog.lists['docs']['include_current_doc']:
                 line[0] = _("Document %d") % (line_idx + 1)
             elif line_idx != 0:
@@ -141,11 +140,13 @@ class ActionEndEditDoc(SimpleAction):
 
 
 class ActionScan(SimpleAction):
+    MARGIN = 10
 
-    def __init__(self, multiscan_win, config, docsearch, main_win):
+    def __init__(self, multiscan_win, config, libinsane, docsearch, main_win):
         SimpleAction.__init__(self, "Start multi-scan")
         self.__multiscan_win = multiscan_win
         self.__config = config
+        self.__libinsane = libinsane
         self.__docsearch = docsearch
         self.__main_win = main_win
 
@@ -169,7 +170,7 @@ class ActionScan(SimpleAction):
 
         try:
             (dev, resolution) = get_scanner(
-                self.__config,
+                self.__config, self.__libinsane,
                 preferred_sources=["ADF", "Feeder"]
             )
         except Exception as exc:
@@ -181,7 +182,7 @@ class ActionScan(SimpleAction):
             raise
 
         try:
-            scan_session = dev.scan(multiple=True)
+            scan_session = dev.scan_start()
         except Exception as exc:
             logger.error("Exception while scanning: {}".format(exc))
             logger.exception(exc)
@@ -192,8 +193,7 @@ class ActionScan(SimpleAction):
 
         page_scans = []
 
-        MARGIN = 10
-        position = (MARGIN, MARGIN)
+        position = (self.MARGIN, self.MARGIN)
 
         rng = range(0, len(self.__multiscan_win.lists['docs']['model']))
         for line_idx in rng:
@@ -220,12 +220,12 @@ class ActionScan(SimpleAction):
                 page_scan.connect("scanworkflow-inst",
                                   drawer.set_scan_workflow)
                 page_scans.append(page_scan)
-                position = (position[0] + drawer.size[0] + MARGIN,
+                position = (position[0] + drawer.size[0] + self.MARGIN,
                             position[1])
-            new_height = position[1] + MARGIN
+            new_height = position[1] + self.MARGIN
             if drawer:
                 new_height += drawer.size[1]
-            position = (MARGIN, new_height)
+            position = (self.MARGIN, new_height)
 
         first_page_scan = page_scans[0]
         last_page_scan = None
@@ -264,7 +264,7 @@ class MultiscanDialog(GObject.GObject):
                            (GObject.TYPE_PYOBJECT,)),
     }
 
-    def __init__(self, main_window, config):
+    def __init__(self, main_window, config, libinsane):
         GObject.GObject.__init__(self)
 
         self.main_window = main_window
@@ -331,7 +331,7 @@ class MultiscanDialog(GObject.GObject):
             ),
             'scan': (
                 [widget_tree.get_object("buttonOk")],
-                ActionScan(self, config, main_window.docsearch,
+                ActionScan(self, config, libinsane, main_window.docsearch,
                            main_window),
             ),
         }
